@@ -1,9 +1,7 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-const Clutter = imports.gi.Clutter;
-const GObject = imports.gi.GObject;
-const IBus = imports.gi.IBus;
+const { Clutter, GObject, IBus } = imports.gi;
+
 const Keyboard = imports.ui.status.keyboard;
-const Signals = imports.signals;
 
 var InputMethod = GObject.registerClass(
 class InputMethod extends Clutter.InputMethod {
