@@ -1,11 +1,7 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
-const GLib = imports.gi.GLib;
-const Gio = imports.gi.Gio;
+const { GLib, Gio, St } = imports.gi;
 const Mainloop = imports.mainloop;
-const St = imports.gi.St;
-const Signals = imports.signals;
-const Atk = imports.gi.Atk;
 
 const Tweener = imports.ui.tweener;
 
