@@ -1,9 +1,6 @@
 /* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
 
-const Atk = imports.gi.Atk;
-const Cairo = imports.cairo;
-const Clutter = imports.gi.Clutter;
-const St = imports.gi.St;
+const { Atk, Clutter, St } = imports.gi;
 const Signals = imports.signals;
 
 var BarLevel = class {
