@@ -1,14 +1,10 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
-const Clutter = imports.gi.Clutter;
-const Meta = imports.gi.Meta;
-const Shell = imports.gi.Shell;
-const St = imports.gi.St;
+const { Clutter, GObject, Meta, Shell, St } = imports.gi;
 
 const Main = imports.ui.main;
 const SwitcherPopup = imports.ui.switcherPopup;
 const Params = imports.misc.params;
-const Tweener = imports.ui.tweener;
 
 var POPUP_APPICON_SIZE = 96;
 var POPUP_FADE_TIME = 0.1; // seconds
@@ -133,10 +129,10 @@ var CtrlAltTabManager = class CtrlAltTabManager {
     }
 };
 
-var CtrlAltTabPopup =
+var CtrlAltTabPopup = GObject.registerClass(
 class CtrlAltTabPopup extends SwitcherPopup.SwitcherPopup {
-    constructor(items) {
-        super(items);
+    _init(items) {
+        super._init(items);
 
         this._switcherList = new CtrlAltTabSwitcher(this._items);
     }
@@ -160,12 +156,12 @@ class CtrlAltTabPopup extends SwitcherPopup.SwitcherPopup {
         super._finish(time);
         Main.ctrlAltTabManager.focusGroup(this._items[this._selectedIndex], time);
     }
-};
+});
 
-var CtrlAltTabSwitcher =
+var CtrlAltTabSwitcher = GObject.registerClass(
 class CtrlAltTabSwitcher extends SwitcherPopup.SwitcherList {
-    constructor(items) {
-        super(true);
+    _init(items) {
+        super._init(true);
 
         for (let i = 0; i < items.length; i++)
             this._addIcon(items[i]);
@@ -187,4 +183,4 @@ class CtrlAltTabSwitcher extends SwitcherPopup.SwitcherList {
 
         this.addItem(box, text);
     }
-};
+});
